pub(crate) enum PatKind<'db> {
Wild,
Never,
Binding {
name: Name,
subpattern: Option<Pat<'db>>,
},
Variant {
substs: GenericArgs<'db>,
enum_variant: EnumVariantId,
subpatterns: Vec<FieldPat<'db>>,
},
Leaf {
subpatterns: Vec<FieldPat<'db>>,
},
Deref {
subpattern: Pat<'db>,
},
LiteralBool {
value: bool,
},
Or {
pats: Vec<Pat<'db>>,
},
}Expand description
Close relative to rustc_mir_build::thir::pattern::PatKind
Variants
Wild
Never
Binding
x, ref x, x @ P, etc.
Variant
Foo(...) or Foo{...} or Foo, where Foo is a variant name from an ADT with
multiple variants.
Leaf
(...), Foo(...), Foo{...}, or Foo, where Foo is a variant name from an ADT with
a single variant.
Deref
&P, &mut P, etc.
LiteralBool
Or
An or-pattern, e.g. p | q.
Invariant: pats.len() >= 2.